<?php 
session_start();
require('../assets/inc/ldapConnect.php');
$mode = (isset($_REQUEST['mode']) && strlen($_REQUEST['mode']) >=1 ) ? $_REQUEST['mode'] : NULL;
$timestamp = (isset($_REQUEST['timestamp']) && strlen($_REQUEST['timestamp']) >=1 ) ? $_REQUEST['timestamp'] : time();


if (isset($_REQUEST['loaded'])) {
	$_SESSION['loaded'] =1;
	audit ($timestamp, "[Contacts] [Warning]","Contacts warning accepted");
	exit();
}


// file check
if ($mode === 'fileCheck') {
	$company = $_REQUEST['company'];
	$file = ($company === '') ? "contacts.out.txt" : "contacts.out.$company.txt";
	$result = (file_exists("/SpliceCom/ftp/$file")) ? '1' : '0';
	echo $result;
	audit ($timestamp, "[Contacts] [FileCheck]","Contacts file checked");
}

//upload file
if ($mode === 'uploadFile') {
	$company = $_REQUEST['company'];
	$uploadFile = "contacts.txt";

if ($company != "00000000-0000-0000-0000-000000000000") {
	$sr = ldap_list($ds,"cn=companies","(&(objectclass=company)(guid=$company))",array('cn')); 
	$info = ldap_get_entries($ds,$sr);	$companyName = $info[0]['cn'][0];
	$uploadFile = "contacts.$companyName.txt";
} 


	$result = 0;
	$filePath = '/SpliceCom/ftp/';
	$tmp_file = $_FILES['myfile']['tmp_name'];
	$filename = $uploadFile;
	
	$target_path = $filePath . $filename;
	$result = move_uploaded_file($tmp_file, $target_path);
	
    echo "<script language='javascript' type='text/javascript'>window.top.window.stopUpload(\"$result\",\"$filename\")</script>";
}
